
Documents and Embedding Config
==============================


Configuration example
-----------------------

.. literalinclude:: ../sample_templates/generic/config_template.yaml
   :language: yaml


Document Config Reference
-------------------------

   .. automodule:: llmsearch.config
      :members:
      :exclude-members: CustomDocumentExtension, get_doc_with_model_config, SuffixAppend, LLMConfig


